* import.c (MAGIC): Changed magic word to avoid confusion about exec
  function vs. exec statement
* bltinmodule.c: renamed the module to __builtin__.
* posixmodule.c (posix_execv): renamed exec --> execv since it is now a
  reserved word.
diff --git a/Modules/posixmodule.c b/Modules/posixmodule.c
index d3f3583..df61c25 100644
--- a/Modules/posixmodule.c
+++ b/Modules/posixmodule.c
@@ -582,7 +582,7 @@
 /* XXX To do: exece, execp */
 
 static object *
-posix_exec(self, args)
+posix_execv(self, args)
 	object *self;
 	object *args;
 {
@@ -592,7 +592,7 @@
 	int i, argc;
 	object *(*getitem) PROTO((object *, int));
 
 	/* exec has two arguments: (path, argv), where
 	   argv is a list or tuple of strings. */
 
 	if (!getargs(args, "(sO)", &path, &argv))
@@ -1180,7 +1180,7 @@
 
 #ifndef MSDOS
 	{"_exit",	posix__exit},
-	{"exec",	posix_exec},
+	{"execv",	posix_execv},
 	{"fork",	posix_fork},
 	{"getegid",	posix_getegid},
 	{"geteuid",	posix_geteuid},
@@ -592,7 +592,7 @@
 	object *(*getitem) PROTO((object *, int));
 
-	/* exec has two arguments: (path, argv), where
+	/* execv has two arguments: (path, argv), where
 	   argv is a list or tuple of strings. */
 